<?php

namespace Drupal\multisite_manager_tool\Controller;

use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\multisite_manager_tool\Form\CacheClearSiteForm;
use Drupal\multisite_manager_tool\Form\CacheClearSitesForm;
use Drupal\multisite_manager_tool\SitesHelper;

/**
 * Returns responses for Multisite manager tool routes.
 */
final class ManageCachesController extends ControllerBase {

  /**
   * Sites helper service.
   *
   * @var \Drupal\multisite_manager_tool\SitesHelper
   */
  protected $sitesHelper;

  public function __construct(
    SitesHelper $sites_helper,
  ) {
    $this->sitesHelper = $sites_helper;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('sites_helper'),
    );
  }

  /**
   * Displays the system multisite manager tool page.
   *
   * @return array
   *   A render array containing the multisite-manager-tool form.
   */
  public function build(): array {

    if (!$this->sitesHelper->checkIfOneSite()) {
      $this->messenger()->addWarning(
        $this->t('Only one site is active, there is no multisite configuration. See the <a href=":ulr" target="_blank">Multisite Drupal</a> page for more information.',
        [':url' => 'https://www.drupal.org/docs/getting-started/multisite-drupal'])
          );
      return [];
    }

    return [
      'cache_clear_sites' => $this->formBuilder()->getForm(CacheClearSitesForm::class),
      'cache_clear_site' => $this->formBuilder()->getForm(CacheClearSiteForm::class),
    ];
  }

}
